@@ -35,8 +35,8 @@ test_that("Boxplot ggplot without log", {
     expect_equal(p$labels, list(x = "expr", y = "time"))
     expect_is(p$layers[[1]]$geom, "GeomBoxplot")
     expect_is(p$layers[[1]]$stat, "StatBoxplot")
-    pp <- print(p)
-    expect_equal(pp$layout$panel_ranges[[1]]$x.labels, c("1 + 1", "2 + 2"))
+    pp <- ggplot2::ggplot_build(p)
+    expect_equal(pp$layout$panel_params[[1]]$x.labels, c("1 + 1", "2 + 2"))
     expect_equal(pp$plot$scales$scales[[2]]$trans$name, "identity")
 })
 
@@ -49,8 +49,8 @@ test_that("Boxplot ggplot with log and horizontal", {
     expect_equal(p$labels, list(x = "expr", y = "time"))
     expect_is(p$layers[[1]]$geom, "GeomBoxplot")
     expect_is(p$layers[[1]]$stat, "StatBoxplot")
-    pp <- print(p)
-    expect_equal(pp$layout$panel_ranges[[1]]$y.labels, c("1 + 1", "2 + 2"))
+    pp <- ggplot2::ggplot_build(p)
+    expect_equal(pp$layout$panel_params[[1]]$y.labels, c("1 + 1", "2 + 2"))
     expect_equal(pp$plot$scales$scales[[1]]$trans$name, "log-10")
 })
 
@@ -63,8 +63,8 @@ test_that("Boxplot ggplot with violin geom", {
     expect_equal(p$labels, list(x = "expr", y = "time"))
     expect_is(p$layers[[1]]$geom, "GeomViolin")
     expect_is(p$layers[[1]]$stat, "StatYdensity")
-    pp <- print(p)
-    expect_equal(pp$layout$panel_ranges[[1]]$x.labels, c("1 + 1", "2 + 2"))
+    pp <- ggplot2::ggplot_build(p)
+    expect_equal(pp$layout$panel_params[[1]]$x.labels, c("1 + 1", "2 + 2"))
     expect_equal(pp$plot$scales$scales[[1]]$trans$name, "log-10")
 })
 
@@ -79,7 +79,7 @@ test_that("Scatter plot ggplot with log", {
     expect_is(p$layers[[1]]$geom, "GeomPoint")
     expect_is(p$layers[[1]]$stat, "StatIdentity")
     expect_equal(p$layers[[1]]$aes_params, list(shape = 19))
-    pp <- print(p)
+    pp <- ggplot2::ggplot_build(p)
     expect_equal(pp$plot$scales$scales[[1]]$trans$name, "log-10")
     expect_equal(pp$plot$scales$scales[[2]]$trans$name, "identity")
 })
@@ -95,7 +95,7 @@ test_that("Scatter plot ggplot without log", {
     expect_is(p$layers[[1]]$geom, "GeomPoint")
     expect_is(p$layers[[1]]$stat, "StatIdentity")
     expect_equal(p$layers[[1]]$aes_params, list(shape = 19))
-    pp <- print(p)
+    pp <- ggplot2::ggplot_build(p)
     expect_equal(pp$plot$scales$scales[[1]]$trans$name, "identity")
     expect_equal(pp$plot$scales$scales[[2]]$trans$name, "identity")
 })
